@@ -4,3 +4,6 @@
 class ReplyMarkup(object):
     def to_json(self):
         raise NotImplementedError
+
+    def __str__(self):
+        return self.to_json()
